import { ColumnsType } from "antd/es/table";
import { formatDateTime } from "../utils/helpers";
import DeviceStatus from "./DeviceStatus";
import DeviceActions from "./DeviceActions";

interface CreateColumnsProps {
  systemTypeTerms: any[];
  deviceTypeTerms: any[];
  onShowDesc: (record: any) => void;
  onEdit: (record: any) => void;
  onDelete: (id: string) => void;
}

export const createColumns = ({
  systemTypeTerms,
  deviceTypeTerms,
  onShowDesc,
  onEdit,
  onDelete,
}: CreateColumnsProps): ColumnsType<any> => {
  // 根据术语ID和类型获取术语名称
  const getTermNameById = (termId: string, termType: string) => {
    if (!termId) return "未知";
    const terms = termType === "system_type" ? systemTypeTerms : deviceTypeTerms;
    const term = terms?.find((t) => t.id === termId);
    return term?.name || "未知";
  };

  return [
    {
      title: "网系类别",
      dataIndex: "systemType",
      key: "systemType",
      align: "center",
      render: (text, record) => {
        return getTermNameById(record.systemType, "system_type");
      },
    },
    {
      title: "故障类型",
      dataIndex: "deviceType",
      key: "deviceType",
      align: "center",
      render: (text, record) => {
        return getTermNameById(record.deviceType, "device_type");
      },
    },
    {
      title: "单位",
      dataIndex: "deptId",
      key: "deptId",
      align: "center",
      render: (text, record) => {
        // 如果有部门关联，显示部门名称
        if (record.deptId && (record as any)?.department?.name) {
          return (record as any)?.department?.name;
        }
        // 否则显示responsiblePerson（如果存在）
        if (record.responsiblePerson) {
          return record.responsiblePerson;
        }
        // 最后才显示未知
        return "未知";
      },
    },
    {
      title: "故障名称",
      dataIndex: "showname",
      key: "showname",
      align: "center",
      render: (text, record) => (
        <div
          onClick={() => onShowDesc(record)}
          style={{
            cursor: "pointer",
            padding: "8px 0",
            fontWeight: "bold",
          }}
        >
          {text || "未命名故障"}
        </div>
      ),
    },
    {
      title: "故障状态",
      dataIndex: "deviceStatus",
      key: "deviceStatus",
      align: "center",
      render: (status) => <DeviceStatus status={status} />,
    },
    {
      title: "时间",
      dataIndex: "createdAt",
      key: "createdAt",
      align: "center",
      render: (text, record) => formatDateTime(record.createdAt),
    },
    {
      title: "操作",
      key: "action",
      align: "center",
      render: (_, record) => (
        <DeviceActions
          record={record}
          onEdit={onEdit}
          onDelete={onDelete}
        />
      ),
    },
  ];
};

export default createColumns;