import { Button } from "antd";
import { ImportOutlined, ExportOutlined } from "@ant-design/icons";
import { useRef } from "react";
import React from "react";

interface TableHeaderProps {
  selectedCount: number;
  onExportTemplate: () => void;
  onImport: (file: File) => void;
  onExport: () => void;
}

const TableHeader: React.FC<TableHeaderProps> = ({
  selectedCount,
  onExportTemplate,
  onImport,
  onExport,
}) => {
  const uploadRef = useRef<HTMLInputElement>(null);

  const handleImportClick = () => {
    if (uploadRef.current) {
      uploadRef.current.click();
    }
  };

  const handleFileChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const files = e.target.files;
    if (!files || files.length === 0) return;
    onImport(files[0]);
    // 清空文件输入，允许再次选择同一文件
    if (uploadRef.current) uploadRef.current.value = "";
  };

  return (
    <div className="w-full flex justify-between mb-2">
      <span></span>
      <div className="flex space-x-2">
        <input
          type="file"
          ref={uploadRef}
          onChange={handleFileChange}
          style={{ display: "none" }}
          accept=".xlsx,.xls,.csv"
        />
        <Button
          icon={<ImportOutlined />}
          type="primary"
          onClick={onExportTemplate}
        >
          下载模板文件
        </Button>
        <Button
          icon={<ImportOutlined />}
          type="primary"
          onClick={handleImportClick}
        >
          导入
        </Button>
        <Button
          type="primary"
          onClick={onExport}
          disabled={selectedCount === 0}
          icon={<ExportOutlined />}
        >
          {selectedCount > 0 ? `导出 (${selectedCount})项数据` : "导出选中数据"}
        </Button>
      </div>
    </div>
  );
};

export default TableHeader;
