import dayjs from "dayjs";

// 提取处理嵌套字段的函数
export const getNestedValue = (record: any, dataIndex: string | string[]) => {
  if (Array.isArray(dataIndex)) {
    return dataIndex.reduce((obj, key) => obj?.[key], record);
  }
  return record[dataIndex];
};

// 根据术语ID和类型获取术语名称
export const getTermNameById = (termId: string, terms: any[], fallback = "未知") => {
  if (!termId) return fallback;
  const term = terms?.find((t) => t.id === termId);
  return term?.name || fallback;
};

// 获取状态键值对应
export const getStatusKeyByValue = (value: string) => {
  const statusMap: Record<string, string> = {
    已修复: "normal",
    维修中: "maintenance",
    "未修复": "broken",
  };
  return statusMap[value] || "normal";
};

// 根据状态获取显示配置
export const getStatusConfig = (status: string) => {
  const statusConfig = {
    normal: {
      text: "已修复",
      color: "success",
    },
    maintenance: {
      text: "维修中",
      color: "processing",
    },
    broken: {
      text: "未修复",
      color: "error",
    },
  };

  return statusConfig[status] || {
    text: "未知",
    color: "default",
  };
};

// 格式化日期时间
export const formatDateTime = (dateTime: string | Date | null) => {
  return dateTime ? dayjs(dateTime).format("YYYY-MM-DD HH:mm:ss") : "未知";
};

// 查找术语ID
export const findTermIdByName = (
  name: string,
  terms: any[]
) => {
  if (!name) return null;
  const term = terms?.find((t) => t.name === name);
  return term?.id || null;
};

// 查找部门ID
export const findDeptIdByName = (name: string, departments: any[], devices: any[]) => {
  if (!name || name === "未知") return null;
  // 直接从部门数据中查找
  const department = departments?.find((dept) => dept.name === name);
  if (department) {
    return department.id;
  }
  // 备用：尝试从设备中查找
  const matchedDevice = devices?.find(
    (device) => (device as any)?.department?.name === name
  );
  return matchedDevice?.deptId || null;
};