import { Button, Avatar, Dropdown, Space } from "antd";
import { UserOutlined, LogoutOutlined, DownOutlined } from "@ant-design/icons";
import { useAuth } from "@web/src/providers/auth-provider";
import { useNavigate, useParams } from "react-router-dom";
import { useMainContext } from "./MainProvider";

export function MainHeader() {
  const { isAuthenticated, user, logout } = useAuth();
  const { id } = useParams();
  const navigate = useNavigate();
  const { searchValue, setSearchValue } = useMainContext();

  const handleLogout = () => {
    logout();
    navigate("/login");
  };

  const items = [
    {
      key: "logout",
      icon: <LogoutOutlined />,
      label: "退出登录",
      danger: true,
    },
  ];

  return (
    <div className="select-none w-full flex items-center justify-between bg-white shadow-md border-b border-gray-100 fixed z-30 py-2 px-4 md:px-6 h-16">
      <div className="flex items-center">
        <span className="text-xl font-bold text-primary">故障收录检索系统</span>
      </div>

      {isAuthenticated && user ? (
        <Dropdown
          menu={{
            items,
            onClick: ({ key }) => key === "logout" && handleLogout(),
          }}
          placement="bottomRight"
          arrow
        >
          <div className="flex items-center cursor-pointer transition-all hover:bg-gray-100 rounded-full py-1 px-3">
            <Avatar
              className="bg-blue-500"
              icon={<UserOutlined />}
              size="default"
            />
            <span className="mx-2 font-medium">
              {user?.showname || user?.username}
            </span>
            <DownOutlined className="text-xs text-gray-500" />
          </div>
        </Dropdown>
      ) : (
        <Button
          type="primary"
          size="large"
          shape="round"
          onClick={() => navigate("/login")}
          icon={<UserOutlined />}
        >
          登录
        </Button>
      )}
    </div>
  );
}
